{{/* vim: set filetype=mustache: */}}
{{/* Expand the name of the chart. */}}
{{- define "cnc.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name. */}}
{{- define "cnc.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}

{{/* Create chart name and version as used by the chart label. */}}
{{- define "cnc.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Common labels */}}
{{- define "chart.labels" -}}
app.kubernetes.io/name: {{ include "cnc.name" . }}
helm.sh/chart: {{ include "cnc.chart" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: "{{ include "cnc.app-version" . }}"
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
chart: {{ .Chart.Name | quote }}
{{- end -}}

{{- define "service.labels" -}}
helm.sh/chart: {{ include "cnc.chart" . }}
{{ include "service.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: "{{ include "cnc.app-version" . }}"
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{- define "service.selectorLabels" -}}
app.kubernetes.io/name: {{ .serviceName }}
app.kubernetes.io/instance: {{ .Release.Name }}
app.kubernetes.io/component: {{ .serviceName }}
app.kubernetes.io/part-of: coverity
{{- end }}

{{- define "cim.common.selectorLabels" -}}
app.kubernetes.io/name: {{ .serviceName }}
app.kubernetes.io/instance: {{ .Release.Name }}
app.kubernetes.io/component: cim
app.kubernetes.io/part-of: coverity
{{- end }}

{{- define "jgroups.service.selectorLabels" -}}
app.kubernetes.io/component: cim
{{- end }}

{{- define "jgroups.service.url" -}}
- name: JGROUPS_DNS_QUERY
  value: {{ include "cnc.fullname" . }}-cim-jgroups-svc.{{ .Release.Namespace }}.svc.cluster.local
{{- end }}

{{- define "cnc.app-version" -}}
{{- printf "%s" .Chart.AppVersion | replace "+" "_" | replace ":" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
https://github.com/openstack/openstack-helm-infra/blob/master/helm-toolkit/templates/utils/_joinListWithComma.tpl
*/}}
{{- define "helm-toolkit.utils.joinListWithComma" -}}
{{- $local := dict "first" true -}}
{{- range $k, $v := . -}}{{- if not $local.first -}},{{- end -}}{{- $v -}}{{- $_ := set $local "first" false -}}{{- end -}}
{{- end -}}


{{- define "cnc.postgres.secret" }}
{{- if not (or .Values.postgres.existingSecret .Values.global.postgres.existingSecret (index .Values .serviceName).postgres.existingSecret) }}
apiVersion: v1
kind: Secret
metadata:
  name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
  namespace: {{ .Release.Namespace }}
  annotations:
    helm.sh/hook-weight: "-14"
    helm.sh/hook: pre-upgrade, pre-install
type: Opaque
stringData:
  host: {{ (index .Values .serviceName).postgres.host | default .Values.postgres.host | default .Values.global.postgres.host | quote }}
  port: {{ (index .Values .serviceName).postgres.port | default .Values.postgres.port | default .Values.global.postgres.port| quote }}
  username: {{ (index .Values .serviceName).postgres.user | default .Values.postgres.user | default .Values.global.postgres.user | quote }}
  password: {{ (index .Values .serviceName).postgres.password | default .Values.postgres.password | default .Values.global.postgres.password | quote }}
{{- end }}
{{- end }}

{{- define "cnc.cim.postgres.jdbcurl" -}}
jdbc:postgresql://${POSTGRES_HOST}:${POSTGRES_PORT}/${POSTGRES_DATABASE}?sslmode={{ (index .Values "cim").postgres.sslmode | default .Values.postgres.sslmode | default .Values.global.postgres.sslmode }}&sslfactory=org.postgresql.ssl.DefaultJavaSSLFactory
{{- end -}}

{{- define "cnc.postgres.environment" }}
{{- if or .Values.postgres.existingSecret .Values.global.postgres.existingSecret (index .Values .serviceName).postgres.existingSecret }}
- name: POSTGRES_HOST
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).postgres.existingSecret | default .Values.postgres.existingSecret | default .Values.global.postgres.existingSecret | quote }}
      key: "host"
- name: POSTGRES_PORT
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).postgres.existingSecret | default .Values.postgres.existingSecret | default .Values.global.postgres.existingSecret | quote }}
      key: "port"
- name: POSTGRES_USERNAME
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).postgres.existingSecret | default .Values.postgres.existingSecret | default .Values.global.postgres.existingSecret | quote }}
      key: "username"
- name: POSTGRES_PASSWORD
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).postgres.existingSecret | default .Values.postgres.existingSecret | default .Values.global.postgres.existingSecret | quote }}
      key: "password"
{{- else }}
- name: POSTGRES_HOST
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "host"
- name: POSTGRES_PORT
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "port"
- name: POSTGRES_USERNAME
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "username"
- name: POSTGRES_PASSWORD
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "password"
{{- end }}
- name: POSTGRES_DATABASE
  value: {{ (index .Values .serviceName).postgres.database | quote }}
{{- end }}


{{- define "cim.contextPath" -}}
{{- if .Values.cim.cimweb.contextPath -}}
{{- .Values.cim.cimweb.contextPath -}}/
{{- else -}}
{{- end -}}
{{- end -}}


{{/*
securityContext for the cim pod level.
*/}}
{{- define "cnc.cim.securityContext.pod" }}
  {{- if .Values.cim.podSecurityContext }}
      {{- with .Values.cim.podSecurityContext }}
      securityContext:
        {{- toYaml . | nindent 8 }}
      {{- end }}
  {{- else }}
      securityContext:
        runAsNonRoot: true
        {{- if .Capabilities.APIVersions.Has "security.openshift.io/v1" }}
        {{- else }}
        runAsUser: 5000
        {{- end }}
  {{- end }}
{{- end }}

{{/* vim: set filetype=mustache: */}}
{{/*
Renders a value that contains template.
Usage:
{{ include "common.tplvalues.render" ( dict "value" .Values.path.to.the.Value "context" $) }}
*/}}
{{- define "common.tplvalues.render" -}}
    {{- if typeIs "string" .value }}
        {{- tpl .value .context }}
    {{- else }}
        {{- tpl (.value | toYaml) .context }}
    {{- end }}
{{- end -}}

{{/*
Check if Kubernetes version is 1.28 or greater and return true or false.
Usage: {{- if isKubeVersionValid .Capabilities.KubeVersion.GitVersion }} ... {{- end }}
*/}}
{{- define "isKubeVersionValid" -}}
{{- $kubeMajorVersion := .Capabilities.KubeVersion.Major | int  }}
{{- $kubeMinorVersion := .Capabilities.KubeVersion.Minor | int }}
{{- if and (ge $kubeMajorVersion 1) (ge $kubeMinorVersion 28) }}
true
{{- end }}
{{- end }}


{{/* Commit rcp4 */}}

{{- define "commitrcp4.image.name" -}}
    {{ printf "%s/%s:%s%s" ((index .Values.cim.commitrcp4 .serviceName).registry | default .Values.imageRegistry | default .Values.global.imageRegistry ) (required "missing image name" (index .Values.cim.commitrcp4 .serviceName).image) ((index .Values.cim.commitrcp4 .serviceName).version | default .Values.imageVersion | default .Values.global.imageVersion) (.Values.imageTagSuffix | default .Values.global.imageTagSuffix ) | quote }}
{{- end }}


{{- define "commitrcp4.postgres.secret" }}
apiVersion: v1
kind: Secret
metadata:
  name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
  namespace: {{ .Release.Namespace }}
  annotations:
    helm.sh/hook-weight: "-14"
    helm.sh/hook: pre-upgrade, pre-install
type: Opaque
stringData:
  host: {{ .Values.cim.postgres.host | default .Values.postgres.host | default .Values.global.postgres.host | quote }}
  port: {{ .Values.cim.postgres.port | default .Values.postgres.port | default .Values.global.postgres.port | quote }}
  username: {{ .Values.cim.postgres.user | default .Values.postgres.user | default .Values.global.postgres.user | quote }}
  password: {{ .Values.cim.postgres.password | default .Values.postgres.password | default .Values.global.postgres.password | quote }}
  database: {{ .Values.cim.postgres.database | quote }}
{{- end }}

{{- define "commitrcp4.postgres.jdbcurl" -}}
jdbc:postgresql://{{ .Values.cim.postgres.host | default .Values.postgres.host | default .Values.global.postgres.host }}:{{ .Values.cim.postgres.port | default .Values.postgres.port | default .Values.global.postgres.port }}/{{ .Values.cim.postgres.database }}?sslmode={{ (index .Values.cim.commitrcp4 "cnc-server-worker").postgres.sslmode | default .Values.postgres.sslmode | default .Values.global.postgres.sslmode }}&sslfactory=org.postgresql.ssl.DefaultJavaSSLFactory
{{- end }}

{{- define "commitrcp4.redis.volumemount" }}
{{- if or .Values.cim.commitrcp4.redis.cacertSecret (index .Values "scan-services" "cache-service").redis.cacertSecret .Values.global.redis.cacertSecret }}
- name: redis-certs
  mountPath: /etc/redis/ssl
{{- end}}
{{- end }}

{{- define "commitrcp4.redis.volume" }}
{{- if or .Values.cim.commitrcp4.redis.cacertSecret (index .Values "scan-services" "cache-service").redis.cacertSecret .Values.global.redis.cacertSecret }}
- name: redis-certs
  secret:
    defaultMode: 420
    secretName: {{ .Values.cim.commitrcp4.redis.cacertSecret | default (index .Values "scan-services" "cache-service").redis.cacertSecret | default .Values.global.redis.cacertSecret }}
{{- end}}
{{- end }}

{{- define "commitrcp4.redis.environment" }}
- name: REDIS_HOST
  value: {{ required "missing redis host" ( .Values.cim.commitrcp4.redis.host | default (index .Values "scan-services" "cache-service").redis.host | default .Values.global.redis.host ) | quote }}
- name: REDIS_PORT
  value: {{ required "missing redis port" ( .Values.cim.commitrcp4.redis.port | default (index .Values "scan-services" "cache-service").redis.port | default .Values.global.redis.port ) | quote }}
- name: REDIS_DATABASE
  value: {{ required "missing redis database" ( .Values.cim.commitrcp4.redis.database ) | quote }}
- name: REDIS_PASSWORD
  {{- if or .Values.cim.commitrcp4.redis.authEnabled (index .Values "scan-services" "cache-service").redis.authEnabled .Values.global.redis.authEnabled }}
  valueFrom:
    secretKeyRef:
      name: {{ required "missing redis passwordSecret" ( .Values.cim.commitrcp4.redis.passwordSecret | default (index .Values "scan-services" "cache-service").redis.passwordSecret | default .Values.global.redis.passwordSecret ) | quote }}
      key: password
      optional: false
  {{- else }}
  value: ""
  {{- end}}
- name: REDIS_SECURE
  value: {{ required "missing redis secure" ( .Values.cim.commitrcp4.redis.secure | default (index .Values "scan-services" "cache-service").redis.secure | default .Values.global.redis.secure ) | quote }}
- name: REDIS_CACERT
  {{- if or .Values.cim.commitrcp4.redis.cacertSecret (index .Values "scan-services" "cache-service").redis.cacertSecret .Values.global.redis.cacertSecret }}
  value: /etc/redis/ssl/ca.crt
  {{- else }}
  value: ""
  {{- end}}
- name: REDIS_VERIFY_HOSTNAME
  value: {{ required "missing redis verifyHostName" ( .Values.cim.commitrcp4.redis.verifyHostName | default (index .Values "scan-services" "cache-service").redis.verifyHostName | default .Values.global.redis.verifyHostName ) | quote }}
{{- end }}

{{- define "commitrcp4.storage.secret" }}
{{- if not (index .Values.cim.commitrcp4 "cnc-storage-proxy").secret.name }}
apiVersion: v1
kind: Secret
metadata:
  name: {{ include "cnc.fullname" . }}-storage-secret
  namespace: {{ .Release.Namespace }}
  annotations:
    helm.sh/hook-weight: "-14"
    helm.sh/hook: pre-upgrade, pre-install
type: Opaque
stringData:
  {{- if eq (index .Values.cim.commitrcp4 "cnc-storage-proxy").storageType "azure" }}
  endpoint: {{ required "missing endpoint" (index .Values.cim.commitrcp4 "cnc-storage-proxy").endpoint | quote }}
  {{- else }}
  access_key: {{ required "missing access key" (index .Values.cim.commitrcp4 "cnc-storage-proxy").accessKey | quote }}
  secret_key: {{ required "missing secret key" (index .Values.cim.commitrcp4 "cnc-storage-proxy").secretKey | quote }}
  {{- end }}
{{- end }}
{{- end }}

{{- define "commitrcp4.storage.environment" }}
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_PROVIDER
  value: {{ (index .Values.cim.commitrcp4 "cnc-storage-proxy").storageType | quote }}
{{- if eq (index .Values.cim.commitrcp4 "cnc-storage-proxy").storageType "azure" }}
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_AZURE_ENDPOINT
  valueFrom:
    secretKeyRef:
      name: {{ if (index .Values.cim.commitrcp4 "cnc-storage-proxy").secret.name }}{{ (index .Values.cim.commitrcp4 "cnc-storage-proxy").secret.name }}{{ else }}{{ include "cnc.fullname" . }}-storage-secret{{ end }}
      key: "endpoint"
{{- else }}
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_ENDPOINT
  value: {{ (index .Values.cim.commitrcp4 "cnc-storage-proxy").endpoint | quote }}
{{- if not (index .Values.cim.commitrcp4 "cnc-storage-proxy").secret.name }}
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_ACCESSKEY
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-storage-secret
      key: "access_key"
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_SECRETKEY
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-storage-secret
      key: "secret_key"
{{- else }}
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_ACCESSKEY
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values.cim.commitrcp4 "cnc-storage-proxy").secret.name }}
      key: "access_key"
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_SECRETKEY
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values.cim.commitrcp4 "cnc-storage-proxy").secret.name }}
      key: "secret_key"
{{- end }}
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_REGION
  value: {{ required "missing region" (index .Values.cim.commitrcp4 "cnc-storage-proxy").region | quote }}
{{- end }}
{{- end }}

{{- define "commitrcp4.common.temporal.environment" }}
- name: TEMPORAL_HOSTPORT
  value: {{ include "cnc.fullname" . }}-cnc-temporal-service:7233
- name: TEMPORAL_NAMESPACE
  value: "server"
- name: TEMPORAL_WORKFLOWRETENTIONINDAYS
  value: "1"
- name: TEMPORAL_EXPIRATIONTIMEOUTINSECONDS
  value: "60"
- name: TEMPORAL_POLLINTERVALINSECONDS
  value: "1"
- name: TEMPORAL_POLLTHREADCOUNT
  value: "30"
{{- end }}

{{/* Common TlsSidecar Parameters */}}

{{- define "tlsSidecar.image.name" -}}
    {{ printf "%s/%s:%s" (.Values.cim.cimweb.tlsSidecar.registry | default .Values.imageRegistry | default .Values.global.imageRegistry ) .Values.cim.cimweb.tlsSidecar.image .Values.cim.cimweb.tlsSidecar.version }}
{{- end }}

{{- define "tlsSidecar.common.volumeMounts" }}
- name: nginx-cert
  mountPath: /app/cert
- name: nginx-config-volume
  mountPath: /etc/nginx
- name: nginx-dhparams
  mountPath: /tmp/ssl
- name: nginx-var-cache
  mountPath: /var/cache/nginx
- name: nginx-var-log
  mountPath: /var/log/nginx
- name: nginx-var-run
  mountPath: /var/run
{{- end }}

{{- define "tlsSidecar.common.ports" }}
- name: p8443
  containerPort: 8443
  protocol: TCP
{{- end }}

{{/* Common Cim Parameters */}}

{{- define "cimweb.common.annotations" }}
checksum/webapp-config: {{ include (print $.Template.BasePath "/webapp-config.yaml") . | sha256sum }}
checksum/nginx-config: {{ include (print $.Template.BasePath "/nginx-config.yaml") . | sha256sum }}
checksum/ldap-config: {{ include (print $.Template.BasePath "/ldap-secret.yaml") . | sha256sum }}
checksum/cim-secret: {{ include (print $.Template.BasePath "/cim-secret.yaml") . | sha256sum }}
{{- if .Values.cim.cimweb.exposeMetrics }}
prometheus.io/port: "8089"
prometheus.io/scrape: "true"
prometheus.io/path: {{ printf "/%smetrics" (include "cim.contextPath" .) | quote }}
{{- end }}
{{- with .Values.cim.cimweb.podAnnotations }}
  {{- toYaml . | nindent 8 }}
{{- end }}
{{- end }}

{{- define "cimweb.image.name" -}}
    {{ printf "%s/%s:%s%s" (.Values.cim.cimweb.registry | default .Values.imageRegistry | default .Values.global.imageRegistry ) .Values.cim.cimweb.image (.Values.cim.cimweb.version | default .Values.imageVersion | default .Values.global.imageVersion ) (.Values.imageTagSuffix | default .Values.global.imageTagSuffix) | quote }}
{{- end }}

{{- define "cimweb.common.environment" }}
- name: TRUST_STORE_PATH
  value: {{ include "connect.truststore.path" . | quote }}
- name: LOG_CONFIG
  value: ""
- name: PROPERTIES_PATH
  value: "/config/cim/cim.properties"
- name: JAVA_OPTS
  value: {{ .Values.cim.cimweb.javaOpts | quote }}
- name: CONTEXT_PATH
  value: {{ .Values.cim.cimweb.contextPath | quote }}
- name: LOAD_CERT_INTO_KEYSTORE
  value: {{ .Values.cim.cimweb.keystore.enabled | quote }}
{{- if (index .Values "scan-services").enabled }}
- name: SCAN_HOST
  value: {{printf "http://"}}{{ include "cnc.fullname" . }}-{{ printf "scan-service:9998/api/v2" }}
- name: STORAGE_HOST
  value: {{printf "http://"}}{{ include "cnc.fullname" . }}-{{ printf "storage-service:9998/api/v2"}}
- name: IMPERSONATION_SECRET
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-impersonation-token
      key: "token"
{{- end }}
{{- if .Values.cim.cimweb.keystore.enabled }}
- name: TLS_CERT_PATH
  value: {{ include "connect.tls.cert.path" . | quote }}
- name: TLS_KEY_PATH
  value: {{ include "connect.tls.key.path" . | quote }}
- name: KEYSTORE_PATH
  value: {{ include "connect.keystore.path" . | quote }}
- name: KEYSTORE_ALIAS
  value: {{ include "connect.keystore.alias" . | quote }}
{{- end }}
{{- range $name, $value := .Values.cim.cimweb.environment }}
- name: {{ $name | quote }}
  value: {{ $value | quote }}
{{- end }}
{{- if or (gt (int .Values.cim.cimweb.replicas) 1) .Values.cim.commitrcp4.enabled }}
- name: CACHE_PROVIDER
  value: infinispancache
- name: LOCK_PROVIDER
  value: jdbclocks
- name: SESSION_PROVIDER
  value: jdbcsessions
- name: INFINISPAN_SECRET_KEY
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-cim-secret-key
      key: "token"
- name: SECRET_KEYSTORE_PATH
  value: {{ include "connect.secret.keystore.path" . | quote }}
{{- end }}
{{- if .Values.cim.commitrcp4.enabled }}
- name: COMMIT_URL
  value: https://{{ (index .Values.cim.ingress.hosts | default .Values.global.ingress.hosts 0) | toString | trimAll "[]" }}/rcp4
- name: COMMIT_PROTOCOL
  value: rcp4
{{- else }}
- name: COMMIT_URL
  value: https://{{ (index .Values.cim.ingress.hosts | default .Values.global.ingress.hosts 0) | toString | trimAll "[]" }}/ccd
- name: COMMIT_PROTOCOL
  value: rcp2
{{- end }}
{{- end }}

{{- define "cimweb.common.volumeMounts" }}
- name: cim-secrets
  mountPath: /config/cim/cim.properties
  subPath: cim.properties
- name: cim-logging
  mountPath: /config/cim/cococo-log4j.xml
  subPath: cococo-log4j.xml
- name: cim-downloads
  mountPath: /coverity/server/base/webapps/downloads
- name: cim-docs
  mountPath: /coverity/webapp/doc
{{- if (index .Values "scan-services").enabled }}
- name: mtls-cert
  mountPath: /app/cert/mtls
{{- end }}
{{- if .Values.cim.cimweb.keystore.enabled }}
- mountPath: /config/cim/cert
  name: cim-certificate
{{- end }}
{{- if or (index .Values "trust-stores").enabled (index .Values.global "trust-stores").enabled }}
- name: importtruststorecerts
  mountPath: /coverity/truststorecerts
{{- end }}
{{- end }}

{{- define "cimdownloads.image.name" -}}
    {{ printf "%s/%s:%s%s" (.Values.cim.cimdownloads.registry | default .Values.imageRegistry | default .Values.global.imageRegistry) .Values.cim.cimdownloads.image (.Values.cim.cimdownloads.version| default .Values.imageVersion | default .Values.global.imageVersion ) (.Values.imageTagSuffix | default .Values.global.imageTagSuffix) | quote }}
{{- end }}

{{- define "cimdocs.common.volumeMounts" }}
- name: cim-docs
  mountPath: /cimweb/docs
{{- end }}

{{- define "cimdownloads.common.volumeMounts" }}
- name: cim-downloads
  mountPath: /cimweb/downloads
{{- end }}

{{- define "cim.common.volumes" }}
{{- if or (index .Values "scan-services").enabled .Values.cim.cimweb.tlsSidecar.enabled }}
- name: nginx-config-volume
  configMap:
    name: {{ include "cnc.fullname" . }}-cim-nginx-config
- name: nginx-dhparams
  configMap:
    name: {{ include "cnc.fullname" . }}-cim-nginx-dhparams
- name: nginx-var-cache
  emptyDir: {}
- name: nginx-var-log
  emptyDir: {}
- name: nginx-var-run
  emptyDir: {}
{{- end }}
- name: cim-secrets
  secret:
    secretName: {{ include "cnc.fullname" . }}-cim-webapp-secrets
- name: cim-properties
  emptyDir: {}
- name: cim-logging
  configMap:
    name: {{ include "cnc.fullname" . }}-cim-logging-config
- name: cim-downloads
  emptyDir: {}
- name: cim-docs
  emptyDir: {}
{{- if .Values.cim.cimweb.keystore.enabled }}
- name: cim-certificate
  secret:
    secretName: {{ .Values.cim.cimweb.keystore.certificateSecret }}
{{- end }}
{{- if or (index .Values "trust-stores").enabled (index .Values.global "trust-stores").enabled }}
- name: importtruststorecerts
  configMap:
    name: {{ (index .Values "trust-stores").configmapName | default (index .Values.global "trust-stores").configmapName }}
{{- end }}
{{- end }}

{{- define "cimweb.common.livenessProbe" }}
httpGet:
  path: {{ printf "/%sliveness" (include "cim.contextPath" .) | quote }}
  port: 8080
initialDelaySeconds: 30
periodSeconds: 30
timeoutSeconds: 60
failureThreshold: 3
{{- end }}

{{- define "cimweb.common.readinessProbe" }}
httpGet:
  path: {{ printf "/%slogin/login.htm" (include "cim.contextPath" .) | quote }}
  port: 8080
initialDelaySeconds: 30
periodSeconds: 45
timeoutSeconds: 30
failureThreshold: 3
{{- end }}

{{- define "cimweb.common.startupProbe" }}
httpGet: 
  path: {{ printf "/%sliveness" (include "cim.contextPath" .) | quote }}
  port: 8080
initialDelaySeconds: 30
periodSeconds: 30
timeoutSeconds: 60
failureThreshold: 30
{{- end }}

{{- define "cimweb.common.ports" }}
- name: p8080
  containerPort: 8080
  protocol: TCP
- name: metrics
  containerPort: 8089
  protocol: TCP
{{- if .Values.cim.cimweb.exposeCommitPort }}
- name: commit
  containerPort: {{ .Values.cim.cimweb.commitPort }}
  protocol: TCP
{{- end }}
{{- end }}